pub enum AtomKind {
Symbol(Symbol),
Bracket {
isotope: Option<Isotope>,
symbol: Symbol,
configuration: Option<Configuration>,
hcount: Option<VirtualHydrogen>,
charge: Option<Charge>,
map: Option<u16>,
},
}Expand description
Minimal context-sensitive representation of an atom kind.
Variants
Implementations
Sourceimpl AtomKind
impl AtomKind
Sourcepub const fn is_aromatic(&self) -> bool
pub const fn is_aromatic(&self) -> bool
Returns true if the kind was defined as being aromatic.
Sourcepub fn invert_configuration(&mut self)
pub fn invert_configuration(&mut self)
Inverts configuration given if it and at least one implicit hydrogen are present.
Panics
Panics given a Configuration other than TH1 or TH2.